arkenOS.
the heart of the mountain. arkenos is a fundamentally new type of operating system—a differentiable, massively parallel kernel built to train and deploy reinforcement-learning agents at scale.
// Direct memory load bypassing CPU
extern "C" __global__ void infer(
float* state_tensor,
float* action_tensor
) {
int idx = blockIdx.x * blockDim.x;
float pos = __ldg(&state[idx]);
action[idx] = policy(pos);
}KERNEL_ARCHITECTURE_MANIFEST
Differentiable Physics
Zero-Copy Memory
Hardware Abstraction
Execution Pipeline
MODULE_02 // LIVE_TENSOR_ALLOCATION
DEPLOYMENT // BARE_METAL_TOPOLOGY
Data Center (Pre-train)
Local Server (Finetune)
Edge Device (Inference)
THE_LOOP // TASK → POLICY → FLEET
one loop takes any agent from task to policy to fleet — a robot body via urdf, or any rl environment. no stack to rebuild, no glue code, no shipping on vibes.
Register Any Agent
a robot body via urdf/mjcf, or any rl environment. one registry for every morphology and task.
Tell Optimus The Goal
describe the objective in plain english. optimus writes the task spec, reward function, and training run.
Train, Local-First
millions of steps/sec on pufferlib — on your own machine. no cloud lock-in, no queue.
Reproducible By Default
reward replay and simulation recipes capture every run, so results are repeatable and impossible to fake.
Verification Gates
prove it, then ship it. policies clear success, reward, safety, and regression gates before release.
One Artifact Out
a single policy.onnx, deployable to sim or hardware. task → policy → fleet.
THE_BET // CAUSE_AND_EFFECT
LLMs read about the world. They've never lived in it.
a language model predicts the next token of a description of the world. an rl agent that runs an environment end-to-end — making every decision itself — internalizes why things happen: cause and effect, not correlation. you don't get that from scraping the internet. you get it from millions of agents living in millions of environments, on a platform that makes those experiments cheap to run and impossible to fake.
Deploy the Kernel.
ready to abandon serial physics? pull the latest kernel image to your cluster and begin hyper-parallel differential training.